@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
-# Copyright (c) 2002-2020 "Neo4j,"
+# Copyright (c) "Neo4j"
 # Neo4j Sweden AB [http://neo4j.com]
 #
 # This file is part of Neo4j.
@@ -45,6 +45,7 @@ Driver API Errors
     + RoutingServiceUnavailable
     + WriteServiceUnavailable
     + ReadServiceUnavailable
+    + IncompleteCommit
   + ConfigurationError
     + AuthConfigurationError
     + CertificateConfigurationError
@@ -60,7 +61,6 @@ Connector API Errors
       + BoltConnectionBroken
       + BoltConnectionClosed
   + BoltFailure
-  + BoltIncompleteCommitError
   + BoltProtocolError
   + Bolt*
 
@@ -88,6 +88,8 @@ class Neo4jError(Exception):
         code = code or "Neo.DatabaseError.General.UnknownError"
         try:
             _, classification, category, title = code.split(".")
+            if code == "Neo.ClientError.Security.AuthorizationExpired":
+                classification = CLASSIFICATION_TRANSIENT
         except ValueError:
             classification = CLASSIFICATION_DATABASE
             category = "General"
@@ -124,6 +126,9 @@ class Neo4jError(Exception):
         else:
             return cls
 
+    def invalidates_all_connections(self):
+        return self.code == "Neo.ClientError.Security.AuthorizationExpired"
+
     def __str__(self):
         return "{{code: {code}}} {{message: {message}}}".format(code=self.code, message=self.message)
 
@@ -286,6 +291,16 @@ class ReadServiceUnavailable(ServiceUnavailable):
     """
 
 
+class IncompleteCommit(ServiceUnavailable):
+    """ Raised when the client looses connection while committing a transaction
+
+    Raised when a disconnection occurs while still waiting for a commit
+    response. For non-idempotent write transactions, this leaves the data
+    in an unknown state with regard to whether the transaction completed
+    successfully or not.
+    """
+
+
 class ResultConsumedError(DriverError):
     """ Raised when trying to access records after the records have been consumed.
     """
@@ -304,3 +319,8 @@ class AuthConfigurationError(ConfigurationError):
 class CertificateConfigurationError(ConfigurationError):
     """ Raised when there is an error with the authentication configuration.
     """
+
+
+class UnsupportedServerProduct(Exception):
+    """ Raised when an unsupported server product is detected.
+    """
